@@ -31,7 +31,7 @@ def populate_font_database():
     fontlist = [
         ":/fontrsrc/fonts/intr-bold.ttf",
         ":/fontrsrc/fonts/intr-rlar.ttf",
-        ":/fontrsrc/fonts/mono-rlar.ttf",
+        ":/fontrsrc/fonts/brlw-rlar.ttf",
         ":/fontrsrc/fonts/fnas-icon.ttf",
     ]
     for indx in fontlist:
@@ -40,6 +40,7 @@ def populate_font_database():
 
 def main():
     os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
+    QApplication.setStyle("Fusion")
     app = QApplication(sys.argv)
     populate_font_database()
     window = MainWind()
